@@ -1,10 +1,9 @@
 package v1
 
-import "github.com/armosec/kubescape/v2/core/cautils"
+import "github.com/kubescape/kubescape/v2/core/cautils"
 
 type ListPolicies struct {
 	Target      string
-	ListIDs     bool
 	Format      string
 	Credentials cautils.Credentials
 }
