@@ -23,7 +23,7 @@ func maskID(id string) string {
 	return strings.TrimSuffix(str, sep)
 }
 
-func ParseHost(urlObj *url.URL) {
+func parseHost(urlObj *url.URL) {
 	if strings.Contains(urlObj.Host, "http://") {
 		urlObj.Scheme = "http"
 		urlObj.Host = strings.Replace(urlObj.Host, "http://", "", 1)
