@@ -2,15 +2,16 @@ package resultshandling
 
 import (
 	"encoding/json"
+	"fmt"
 
-	"github.com/armosec/kubescape/v2/core/cautils"
-	"github.com/armosec/kubescape/v2/core/pkg/resultshandling/printer"
-	printerv1 "github.com/armosec/kubescape/v2/core/pkg/resultshandling/printer/v1"
-	printerv2 "github.com/armosec/kubescape/v2/core/pkg/resultshandling/printer/v2"
-	"github.com/armosec/kubescape/v2/core/pkg/resultshandling/reporter"
-	reporthandlingv2 "github.com/armosec/opa-utils/reporthandling/v2"
-	logger "github.com/dwertent/go-logger"
-	"github.com/dwertent/go-logger/helpers"
+	logger "github.com/kubescape/go-logger"
+	"github.com/kubescape/go-logger/helpers"
+	"github.com/kubescape/kubescape/v2/core/cautils"
+	"github.com/kubescape/kubescape/v2/core/pkg/resultshandling/printer"
+	printerv1 "github.com/kubescape/kubescape/v2/core/pkg/resultshandling/printer/v1"
+	printerv2 "github.com/kubescape/kubescape/v2/core/pkg/resultshandling/printer/v2"
+	"github.com/kubescape/kubescape/v2/core/pkg/resultshandling/reporter"
+	reporthandlingv2 "github.com/kubescape/opa-utils/reporthandling/v2"
 )
 
 type ResultsHandler struct {
@@ -61,7 +62,7 @@ func (resultsHandler *ResultsHandler) GetResults() *reporthandlingv2.PostureRepo
 	return printerv2.FinalizeResults(resultsHandler.scanData)
 }
 
-// HandleResults handle the scan results according to the pre defind interfaces
+// HandleResults handle the scan results according to the pre defined interfaces
 func (resultsHandler *ResultsHandler) HandleResults() error {
 
 	resultsHandler.printerObj.ActionPrint(resultsHandler.scanData)
@@ -77,7 +78,7 @@ func (resultsHandler *ResultsHandler) HandleResults() error {
 	return nil
 }
 
-// NewPrinter defind output format
+// NewPrinter defined output format
 func NewPrinter(printFormat, formatVersion string, verboseMode bool, viewType cautils.ViewTypes) printer.IPrinter {
 
 	switch printFormat {
@@ -86,7 +87,7 @@ func NewPrinter(printFormat, formatVersion string, verboseMode bool, viewType ca
 		case "v2":
 			return printerv2.NewJsonPrinter()
 		default:
-			logger.L().Warning("Deprecated format version", helpers.String("run", "--format-version=v2"))
+			logger.L().Warning("Deprecated format version", helpers.String("run", "--format-version=v2"), helpers.String("This will not be supported after", "1/Jan/2023"))
 			return printerv1.NewJsonPrinter()
 		}
 	case printer.JunitResultFormat:
@@ -97,7 +98,12 @@ func NewPrinter(printFormat, formatVersion string, verboseMode bool, viewType ca
 		return printerv2.NewPdfPrinter()
 	case printer.HtmlFormat:
 		return printerv2.NewHtmlPrinter()
+	case printer.SARIFFormat:
+		return printerv2.NewSARIFPrinter()
 	default:
+		if printFormat != printer.PrettyFormat {
+			logger.L().Error(fmt.Sprintf("Invalid format \"%s\", default format \"pretty-printer\" is applied", printFormat))
+		}
 		return printerv2.NewPrettyPrinter(verboseMode, formatVersion, viewType)
 	}
 }
