@@ -3,13 +3,16 @@ package score
 import (
 	"fmt"
 
-	"github.com/armosec/opa-utils/score"
+	"github.com/kubescape/opa-utils/score"
 
-	"github.com/armosec/kubescape/v2/core/cautils"
+	"github.com/kubescape/kubescape/v2/core/cautils"
 )
 
-/* provides a wrapper for scoreUtils, since there's no common interface between postureReportV1 and PostureReportV2
+/*
+	provides a wrapper for scoreUtils, since there's no common interface between postureReportV1 and PostureReportV2
+
 and the need of concrete objects
+
 	I've decided to create scoreWrapper that will allow calculating score regardless (as long as opaSessionObj is there)
 */
 type ScoreWrapper struct {
@@ -25,10 +28,7 @@ const (
 )
 
 func (su *ScoreWrapper) Calculate(reportVersion PostureReportVersion) error {
-	switch reportVersion {
-	case EPostureReportV1:
-		return su.scoreUtil.Calculate(su.opaSessionObj.PostureReport.FrameworkReports)
-	case EPostureReportV2:
+	if reportVersion == EPostureReportV2 {
 		return su.scoreUtil.CalculatePostureReportV2(su.opaSessionObj.Report)
 	}
 
