@@ -3,14 +3,14 @@ package v1
 import (
 	"encoding/json"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"sync"
 
-	"github.com/armosec/kubescape/v2/core/cautils"
-	utilsmetav1 "github.com/armosec/opa-utils/httpserver/meta/v1"
-	logger "github.com/dwertent/go-logger"
-	"github.com/dwertent/go-logger/helpers"
+	logger "github.com/kubescape/go-logger"
+	"github.com/kubescape/go-logger/helpers"
+	"github.com/kubescape/kubescape/v2/core/cautils"
+	utilsmetav1 "github.com/kubescape/opa-utils/httpserver/meta/v1"
 
 	"github.com/gorilla/schema"
 )
@@ -57,18 +57,46 @@ func newScanResponseChan() *scanResponseChan {
 }
 
 type ScanQueryParams struct {
-	ReturnResults bool `schema:"wait"` // wait for scanning to complete (synchronized request)
-	KeepResults   bool `schema:"keep"` // do not delete results after returning (relevant only for synchronized requests)
+	// Wait for scanning to complete (synchronous request)
+	// default: false
+	ReturnResults bool `schema:"wait" json:"wait"`
+	// Do not delete results after returning (relevant only for synchronous requests)
+	// default: false
+	KeepResults bool `schema:"keep" json:"keep"`
 }
 
+// swagger:parameters getScanResults
+type GetResultsQueryParams struct {
+	// ID of the requested scan. If empty or not provided, defaults to the latest scan.
+	//
+	// in: query
+	ScanID string `schema:"id" json:"id"`
+	// Keep the results in local storage after returning them.
+	//
+	// By default, the Kubescape Microservice will delete scan results.
+	//
+	// in: query
+	// default: false
+	KeepResults bool `schema:"keep" json:"keep"`
+}
+
+// swagger:parameters deleteScanResults
 type ResultsQueryParams struct {
-	ScanID      string `schema:"id"`
-	KeepResults bool   `schema:"keep"` // do not delete results after returning (default will delete results)
-	AllResults  bool   `schema:"all"`  // delete all results
+	GetResultsQueryParams
+	// Whether to delete all results
+	//
+	// in: query
+	// default: false
+	AllResults bool `schema:"all" json:"all"`
 }
 
+// swagger:parameters getStatus
 type StatusQueryParams struct {
-	ScanID string `schema:"id"`
+	// ID of the scan to check
+	//
+	// in:query
+	// swagger:strfmt uuid4
+	ScanID string `schema:"id" json:"id"`
 }
 
 // scanRequestParams params passed to channel
@@ -78,6 +106,14 @@ type scanRequestParams struct {
 	scanID          string            // generated scan ID
 }
 
+// swagger:parameters triggerScan
+type ScanRequest struct {
+	ScanQueryParams
+	// Scan parameters
+	// in:body
+	Body utilsmetav1.PostScanRequest
+}
+
 func getScanParamsFromRequest(r *http.Request, scanID string) (*scanRequestParams, error) {
 	defer r.Body.Close()
 
@@ -88,7 +124,7 @@ func getScanParamsFromRequest(r *http.Request, scanID string) (*scanRequestParam
 		return scanRequestParams, fmt.Errorf("failed to parse query params, reason: %s", err.Error())
 	}
 
-	readBuffer, err := ioutil.ReadAll(r.Body)
+	readBuffer, err := io.ReadAll(r.Body)
 	if err != nil {
 		// handler.writeError(w, fmt.Errorf("failed to read request body, reason: %s", err.Error()), scanID)
 		return scanRequestParams, fmt.Errorf("failed to read request body, reason: %s", err.Error())
