@@ -3,20 +3,29 @@ package v1
 import (
 	"fmt"
 	"net/http"
+	_ "net/http/pprof"
 
-	utilsapisv1 "github.com/armosec/opa-utils/httpserver/apis/v1"
-	utilsmetav1 "github.com/armosec/opa-utils/httpserver/meta/v1"
-	"github.com/dwertent/go-logger/helpers"
+	"github.com/kubescape/go-logger/helpers"
+	utilsapisv1 "github.com/kubescape/opa-utils/httpserver/apis/v1"
+	utilsmetav1 "github.com/kubescape/opa-utils/httpserver/meta/v1"
 
 	"github.com/gorilla/schema"
 
-	logger "github.com/dwertent/go-logger"
+	logger "github.com/kubescape/go-logger"
 
 	"github.com/google/uuid"
 )
 
-var OutputDir = "./results"
-var FailedOutputDir = "./failed"
+var OutputDir = "./results/"
+var FailedOutputDir = "./failed/"
+
+// A Scan Response object
+//
+// swagger:response scanResponse
+type ScanResponse struct {
+	// in:body
+	Body utilsmetav1.Response
+}
 
 type HTTPHandler struct {
 	state            *serverState
