@@ -1,12 +1,14 @@
 package main
 
 import (
-	"github.com/armosec/kubescape/v2/cmd"
-	logger "github.com/dwertent/go-logger"
+	logger "github.com/kubescape/go-logger"
+	"github.com/kubescape/kubescape/v2/cmd"
+	
 )
 
 func main() {
 	if err := cmd.Execute(); err != nil {
 		logger.L().Fatal(err.Error())
 	}
+
 }
